@@ -1,6 +1,7 @@
-#!/usr/bin/python3
 """Test the operation of the tinydns utilities."""
 
+from __future__ import annotations
+
 import argparse
 import dataclasses
 import errno
@@ -99,7 +100,7 @@ def fixup_tempd_group(cfg: Config, tempd: pathlib.Path) -> None:
     except OSError as err:
         failed = True
         cfg.diag(f"- failed: {err}")
-        if err.errno not in (errno.EPERM, errno.EACCES):
+        if err.errno not in {errno.EPERM, errno.EACCES}:
             raise
 
     if not failed:
@@ -116,10 +117,7 @@ def fixup_tempd_group(cfg: Config, tempd: pathlib.Path) -> None:
     cfg.diag(f"- tempd gid: {tempd_gid} our gid: {our_gid}")
     if tempd_gid == our_gid:
         sys.exit("Don't know how to handle things with the same group ID")
-    cfg.diag(
-        f"Trying to change the group ID of {tempd} "
-        f"from {tempd_gid} to {our_gid}"
-    )
+    cfg.diag(f"Trying to change the group ID of {tempd} from {tempd_gid} to {our_gid}")
     os.chown(tempd, tempd_stat.st_uid, our_gid)
 
     cfg.diag("Now retrying the test")
@@ -130,7 +128,7 @@ def fixup_tempd_group(cfg: Config, tempd: pathlib.Path) -> None:
 
 
 def main() -> None:
-    """Main program: parse options, run the tests."""
+    """Parse options, run the tests."""
     cfg = parse_arguments()
     with tempfile.TemporaryDirectory() as tempd_obj:
         tempd = pathlib.Path(tempd_obj).absolute()
