@@ -1,32 +1,29 @@
 """Test the `tinydns` and `dnsq` programs."""
 
+from __future__ import annotations
+
 import dataclasses
 import enum
 import os
-import pathlib
 import socket
 import struct
-import subprocess
+import subprocess  # noqa: S404
 import sys
 import time
-
-from typing import (
-    Callable,  # noqa: H301
-    Dict,
-    List,
-    Tuple,
-    Union,
-    TYPE_CHECKING,
-)
+import typing
 
 from . import defs
 from . import test_get
 
 
-if TYPE_CHECKING:
-    PopenStr = subprocess.Popen[str]  # pylint: disable=unsubscriptable-object
-else:
-    PopenStr = subprocess.Popen
+if typing.TYPE_CHECKING:
+    import pathlib
+    from collections.abc import Callable
+
+
+QUERY_PROGRESS = 10000
+
+PORT_DNS = 53
 
 
 class ProcessFDType(str, enum.Enum):
@@ -66,7 +63,7 @@ class ProcessInfo:
     uid: int
     username: str
 
-    files: List[ProcessFDInfo]
+    files: list[ProcessFDInfo]
 
 
 @dataclasses.dataclass
@@ -74,10 +71,10 @@ class ParseProcessInfo:
     """Parse the output of `lsof -F` for our very limited testing needs."""
 
     cfg: defs.Config
-    cproc: Dict[str, str] = dataclasses.field(default_factory=dict)
-    cfile: Dict[str, str] = dataclasses.field(default_factory=dict)
-    cfiles: List[ProcessFDInfo] = dataclasses.field(default_factory=list)
-    result: Dict[int, ProcessInfo] = dataclasses.field(default_factory=dict)
+    cproc: dict[str, str] = dataclasses.field(default_factory=dict)
+    cfile: dict[str, str] = dataclasses.field(default_factory=dict)
+    cfiles: list[ProcessFDInfo] = dataclasses.field(default_factory=list)
+    result: dict[int, ProcessInfo] = dataclasses.field(default_factory=dict)
 
     def finish_file_ipv4(self) -> ProcessFDInfo:
         """Store the information about a socket."""
@@ -124,30 +121,28 @@ class ParseProcessInfo:
         if pdata.pid in self.result:
             sys.exit(
                 f"lsof output a duplicate process set for {pdata.pid}: "
-                f"first {self.result[pdata.pid]!r} now {pdata!r}"
+                f"first {self.result[pdata.pid]!r} now {pdata!r}",
             )
         self.result[pdata.pid] = pdata
 
-    def parse(self, lines: List[str]) -> Dict[int, ProcessInfo]:
+    def parse(self, lines: list[str]) -> dict[int, ProcessInfo]:
         """Parse some lsof output lines."""
 
         def h_process(_first: str, rest: str) -> None:
-            """A new process set."""
+            """Start parsing a new process set."""
             if self.cproc:
                 self.finish_process()
 
             self.cproc["pid"] = rest
 
         def h_file(_first: str, rest: str) -> None:
-            """A new file descriptor set."""
+            """Start parsing a new file descriptor set."""
             if self.cfile:
                 self.finish_file()
 
             self.cfile["fileno"] = rest
 
-        handlers: Dict[
-            str, Union[Callable[[str, str], None], Tuple[Dict[str, str], str]]
-        ] = {
+        handlers: dict[str, Callable[[str, str], None] | tuple[dict[str, str], str]] = {
             "p": h_process,
             "g": (self.cproc, "pgid"),
             "R": (self.cproc, "tid"),
@@ -181,9 +176,7 @@ class ParseProcessInfo:
         return self.result
 
 
-def check_single_udp_socket(
-    processes: Dict[int, ProcessInfo], pid: int, ipaddr: str
-) -> bool:
+def check_single_udp_socket(processes: dict[int, ProcessInfo], pid: int, ipaddr: str) -> bool:
     """Make sure tinydns is only listening on a single UDP socket."""
     pdata = processes.get(pid)
     if pdata is None or len(pdata.files) != 1:
@@ -193,13 +186,13 @@ def check_single_udp_socket(
     if not isinstance(data, ProcessSocketFDInfo):
         return False
 
-    return data.proto == "UDP" and data.address == ipaddr and data.port == 53
+    return data.proto == "UDP" and data.address == ipaddr and data.port == PORT_DNS
 
 
 def run_tinydns(
     cfg: defs.Config,
     tempd: pathlib.Path,
-    callback: Callable[[PopenStr, str], None],
+    callback: Callable[[subprocess.Popen[str], str], None],
 ) -> None:
     """Test the `tinydns` and `dnsq` programs."""
     ipaddr = defs.RECORDS[0].address
@@ -208,7 +201,7 @@ def run_tinydns(
         sys.exit(f"Expected {svcdir} to be a directory")
     os.chdir(svcdir)
 
-    with subprocess.Popen(
+    with subprocess.Popen(  # noqa: S603
         ["./run"],
         shell=False,
         env=cfg.subenv,
@@ -218,7 +211,7 @@ def run_tinydns(
     ) as proc:
         try:
             print(f"- spawned process {proc.pid}")
-            assert proc.stdout is not None
+            assert proc.stdout is not None  # noqa: S101  # mypy needs this
             print("- waiting for the 'starting tinydns' line")
             line = proc.stdout.readline()
             print(f"- got line {line!r}")
@@ -235,15 +228,12 @@ def run_tinydns(
                     str(proc.pid),
                     "-F",
                     "-i4udp:53",
-                ]
+                ],
             ).splitlines()
             cfg.diag(f"lsof output: {lines!r}")
             processes = ParseProcessInfo(cfg).parse(lines)
             if not check_single_udp_socket(processes, proc.pid, ipaddr):
-                sys.exit(
-                    f"tinydns should listen on a single UDP socket: "
-                    f"{processes!r}"
-                )
+                sys.exit(f"tinydns should listen on a single UDP socket: {processes!r}")
             print(f"- tinydns is listening at {ipaddr}:53")
             callback(proc, ipaddr)
         finally:
@@ -273,9 +263,9 @@ def test_tinydns_run(cfg: defs.Config, tempd: pathlib.Path) -> None:
     if not dnsq.is_file() or not os.access(dnsq, os.X_OK):
         sys.exit(f"Not an executable file: {dnsq}")
 
-    def test_dnsq(proc: PopenStr, ipaddr: str) -> None:
+    def test_dnsq(proc: subprocess.Popen[str], ipaddr: str) -> None:
         """Run `dnsq` against the specified `tinydns` instance."""
-        assert proc.stdout is not None
+        assert proc.stdout is not None  # noqa: S101  # mypy needs this
 
         for rec in defs.RECORDS:
             rdef = defs.TYPES[rec.rtype]
@@ -310,9 +300,9 @@ def test_tinydns_run_udp(cfg: defs.Config, tempd: pathlib.Path) -> None:
         print("- not running as root, skipped")
         return
 
-    def test_dnsq(proc: PopenStr, ipaddr: str) -> None:
+    def test_dnsq(proc: subprocess.Popen[str], ipaddr: str) -> None:
         """Run `dnsq` against the specified `tinydns` instance."""
-        assert proc.stdout is not None
+        assert proc.stdout is not None  # noqa: S101  # mypy needs this
 
         pkt = struct.pack(
             ">HHHHHH8p4p1pHH",
@@ -330,12 +320,10 @@ def test_tinydns_run_udp(cfg: defs.Config, tempd: pathlib.Path) -> None:
         )
         print(f"- query packet: {pkt!r}")
 
-        sock = socket.socket(
-            socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_UDP
-        )
+        sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_UDP)
         sock.connect((ipaddr, 53))
 
-        for idx in range(1000000):
+        for idx in range(QUERY_PROGRESS * 100):
             pkt = struct.pack(">H", (idx + 17) % 65536) + pkt[2:]
             sent = sock.send(pkt)
             if sent != len(pkt):
@@ -343,24 +331,18 @@ def test_tinydns_run_udp(cfg: defs.Config, tempd: pathlib.Path) -> None:
 
             line = proc.stdout.readline()
             if "+" not in line:
-                sys.exit(
-                    f"Query {idx + 1}: expected a '+' in "
-                    f"the tinydns log line {line!r}"
-                )
+                sys.exit(f"Query {idx + 1}: expected a '+' in the tinydns log line {line!r}")
 
             resp = sock.recv(4096)
             if resp[:2] != pkt[:2]:
-                sys.exit(
-                    f"Query {idx + 1}: unexpected ID: "
-                    f"query {pkt!r} response {resp!r}"
-                )
+                sys.exit(f"Query {idx + 1}: unexpected ID: query {pkt!r} response {resp!r}")
             if resp[4:8] != b"\x00\x01\x00\x01":
                 sys.exit(
                     f"Query {idx + 1}: unexpected query/response count: "
-                    f"query {pkt!r} response {resp!r}"
+                    f"query {pkt!r} response {resp!r}",
                 )
 
-            if (idx % 10000) == 9999:
+            if (idx % QUERY_PROGRESS) == QUERY_PROGRESS - 1:
                 print(f"- sent {idx + 1} queries to {ipaddr}")
 
     run_tinydns(cfg, tempd, test_dnsq)
